# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SearchSortingProperty(str, Enum):
    """
    Indicates how the search result entities should be sorted
    """

    """
    allowed enum values
    """
    NAME = 'name'
    CREATIONDATE = 'creationDate'
    MODIFICATIONDATE = 'modificationDate'
    IMPORTDATE = 'importDate'
    UPDATEDATE = 'updateDate'
    BINARYSIZE = 'binarySize'
    WIDTH = 'width'
    HEIGHT = 'height'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchSortingProperty from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.manifest_instructions import ManifestInstructions

class TestManifestInstructions(unittest.TestCase):
    """ManifestInstructions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ManifestInstructions:
        """Test ManifestInstructions
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ManifestInstructions`
        """
        model = ManifestInstructions()
        if include_optional:
            return ManifestInstructions(
                events = [
                    'process.started'
                    ],
                capabilities = [
                    picteus_ws_client.models.manifest_capability.ManifestCapability(
                        id = image.embeddings, )
                    ],
                throttling_policies = [
                    picteus_ws_client.models.manifest_throttling_policy.ManifestThrottlingPolicy(
                        events = [
                            'process.started'
                            ], 
                        duration_in_milliseconds = 1000, 
                        maximum_count = 10, )
                    ],
                execution = picteus_ws_client.models.manifest_execution.ManifestExecution(
                    executable = 'python', 
                    arguments = [
                        '0'
                        ], ),
                commands = [
                    picteus_ws_client.models.manifest_extension_command.ManifestExtensionCommand(
                        id = 'convert', 
                        on = null, 
                        parameters = picteus_ws_client.models.parameters.parameters(), 
                        specifications = [
                            picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                                locale = 'en', 
                                label = 'Resize an image', 
                                description = 'Resizes an image given a format asked to the user.', )
                            ], )
                    ]
            )
        else:
            return ManifestInstructions(
                events = [
                    'process.started'
                    ],
                execution = picteus_ws_client.models.manifest_execution.ManifestExecution(
                    executable = 'python', 
                    arguments = [
                        '0'
                        ], ),
        )
        """

    def testManifestInstructions(self):
        """Test ManifestInstructions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_filter import SearchFilter

class TestSearchFilter(unittest.TestCase):
    """SearchFilter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchFilter:
        """Test SearchFilter
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchFilter`
        """
        model = SearchFilter()
        if include_optional:
            return SearchFilter(
                criteria = picteus_ws_client.models.search_criteria.SearchCriteria(
                    formats = [PNG, JPEG], 
                    keyword = null, 
                    tags = null, 
                    features = null, 
                    properties = null, ),
                origin = None,
                sorting = picteus_ws_client.models.search_sorting.SearchSorting(
                    property = name, 
                    is_ascending = True, )
            )
        else:
            return SearchFilter(
        )
        """

    def testSearchFilter(self):
        """Test SearchFilter"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
